archive_rotator package
=======================

Submodules
----------

archive_rotator.algorithms module
---------------------------------

.. automodule:: archive_rotator.algorithms
    :members:
    :undoc-members:
    :show-inheritance:

archive_rotator.cli module
--------------------------

.. automodule:: archive_rotator.cli
    :members:
    :undoc-members:
    :show-inheritance:

archive_rotator.rotator module
------------------------------

.. automodule:: archive_rotator.rotator
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: archive_rotator
    :members:
    :undoc-members:
    :show-inheritance:
